Re-exports
pub extern crate ark_std;
Modules
- merkle_
tree - This file provides the R1CS constraints implementation of the Sparse Merkle tree data structure. For a more through description of the sparse merkle tree data structure refer to arkworks_native_gadgets::merkle_tree
- poseidon
- A R1CS contraint generation implementation of the Poseidon hash function.
- set